@@ -37,3 +37,9 @@ class Polymorphism(object):
     def is_transversion(self):
         return self.is_substitution() and not self.is_transition()
 
+    def is_insertion(self):
+        return self.insert > 0
+
+    def is_deletion(self):
+        return self.value in ['-']
+
