@@ -35,7 +35,7 @@ def flatten(item):
         return [item]
 
 
-def sites2seq(sites, region='HVR1'):
+def sites2seq(sites, region='HVR1', add16k=False):
     """
     Translate sites to sequence.
 
@@ -95,9 +95,9 @@ def sites2seq(sites, region='HVR1'):
     if (type(sites) == StringType):
         if sites.upper() == 'RCRS':
             sites = ''
-        sites = str2sites(sites)
+        sites = str2sites(sites,add16k=add16k)
     elif (type(sites) == ListType):
-        sites = flatten(list(str2sites(x) for x in sites))
+        sites = flatten(list(str2sites(x,add16k=add16k) for x in sites))
     else:
         raise Exception('"sites" argument "%s" is not acceptable' % type(sites))
 
